==> react-overlay-pack-3.0.4.tgz: package/es/DomAlign/DomAlign.js <==
var _class, _temp2;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/* global window */
import * as React from 'react';
import PropTypes from 'prop-types';
import domAlign from 'dom-align';
import rafThrottle from 'raf-throttle';

var DomAlign = (_temp2 = _class = function (_React$Component) {
  _inherits(DomAlign, _React$Component);

  function DomAlign() {
    var _temp, _this, _ret;

    _classCallCheck(this, DomAlign);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _React$Component.call.apply(_React$Component, [this].concat(args))), _this), _this.source = React.createRef(), _this.align = rafThrottle(function () {
      var _this$props = _this.props,
          target = _this$props.target,
          config = _this$props.config;
      var _this2 = _this,
          source = _this2.source;


      if (target && target.current && source && source.current) {
        // Note: Wait for two react instance ready.
        domAlign(source.current, target.current, config);
      }
    }), _temp), _possibleConstructorReturn(_this, _ret);
  }

  DomAlign.prototype.componentDidMount = function componentDidMount() {
    var resize = this.props.resize;

    this.align();
    if (resize) {
      window.addEventListener('resize', this.align);
      window.addEventListener('scroll', this.align);
      window.addEventListener('wheel', this.align);
    }
  };

  DomAlign.prototype.componentDidUpdate = function componentDidUpdate() {
    var _this3 = this;

    // TODO: make it async. there is a problem of overlay in dialog case.
    this.timeoutId = setTimeout(function () {
      return _this3.align();
    });
  };

  DomAlign.prototype.componentWillUnmount = function componentWillUnmount() {
    var resize = this.props.resize;

    if (resize) {
      window.removeEventListener('resize', this.align);
      window.removeEventListener('scroll', this.align);
      window.removeEventListener('wheel', this.align);
    }
    if (this.align && this.align.cancel) this.align.cancel();
    if (this.timeoutId) clearTimeout(this.timeoutId);
  };

  DomAlign.prototype.render = function render() {
    var children = this.props.children;
    var source = this.source;


    return React.cloneElement(React.Children.only(children), {
      ref: source
    });
  };

  return DomAlign;
}(React.Component), _class.defaultProps = {
  target: undefined,
  resize: false
}, _temp2);
DomAlign.propTypes = process.env.NODE_ENV !== "production" ? {
  children: PropTypes.element.isRequired,
  config: PropTypes.object.isRequired,
  target: PropTypes.object,
  resize: PropTypes.bool
} : {};


export default DomAlign;

==> react-overlay-pack-3.0.6.tgz: package/es/DomAlign/DomAlign.js <==
var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/* global window */
import * as React from 'react';
import PropTypes from 'prop-types';
import domAlign from 'dom-align';
import rafThrottle from 'raf-throttle';

var DomAlign = (_temp = _class = function (_React$Component) {
  _inherits(DomAlign, _React$Component);

  function DomAlign(props) {
    _classCallCheck(this, DomAlign);

    var _this = _possibleConstructorReturn(this, _React$Component.call(this, props));

    _this.source = React.createRef();
    _this.align = rafThrottle(function () {
      var _this$props = _this.props,
          target = _this$props.target,
          config = _this$props.config;
      var source = _this.source;


      if (target && target.current && source && source.current) {
        // Note: Wait for two react instance ready.
        domAlign(source.current, target.current, config);
      }
    });
    return _this;
  }

  DomAlign.prototype.componentDidMount = function componentDidMount() {
    var resize = this.props.resize;

    this.align();
    if (resize) {
      window.addEventListener('resize', this.align);
      window.addEventListener('scroll', this.align);
      window.addEventListener('wheel', this.align);
    }
  };

  DomAlign.prototype.componentDidUpdate = function componentDidUpdate() {
    var _this2 = this;

    // TODO: make it async. there is a problem of overlay in dialog case.
    this.timeoutId = setTimeout(function () {
      return _this2.align();
    });
  };

  DomAlign.prototype.componentWillUnmount = function componentWillUnmount() {
    var resize = this.props.resize;

    if (resize) {
      window.removeEventListener('resize', this.align);
      window.removeEventListener('scroll', this.align);
      window.removeEventListener('wheel', this.align);
    }
    if (this.align && this.align.cancel) this.align.cancel();
    if (this.timeoutId) clearTimeout(this.timeoutId);
  };

  DomAlign.prototype.render = function render() {
    var children = this.props.children;
    var source = this.source;


    return React.cloneElement(React.Children.only(children), {
      ref: source
    });
  };

  return DomAlign;
}(React.Component), _class.defaultProps = {
  target: undefined,
  resize: false
}, _temp);
DomAlign.propTypes = process.env.NODE_ENV !== "production" ? {
  children: PropTypes.element.isRequired,
  config: PropTypes.object.isRequired,
  target: PropTypes.object,
  resize: PropTypes.bool
} : {};


export default DomAlign;
